@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -97,7 +97,7 @@ public class Day implements Comparable<Day> {
 
     @Override
     public String toString() {
-        com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(time.toString());
+        StringBuilder sb = new StringBuilder(time.toString());
         sb.append(':');
         sb.append(appointments.toString());
         return sb.toString();
